ClientHandshakeEvent

Enum ClientHandshakeEvent 

pub enum ClientHandshakeEvent<'a> {
    Send,
    Receive,
    VerifyServerCertificate,
    Done {
        ciphersuite: CipherSuite,
        tls_version: u16,
        key_exchange_group: KeyExchangeGroup,
        signature_scheme: SignatureScheme,
        alpn: &'a [u8],
    },
    Closed,
}
Events produced by the handshake state machine.

Returned by start_handshake and continue_handshake.

Variants



Send

The caller should transmit outgoing_data over the network, then call continue_handshake.



Receive

The caller should read data from the network into receive_buffer, call commit_received, then call continue_handshake.



VerifyServerCertificate

The server’s certificate has been received and must be validated by the caller. Use server_certificate to access the certificate and server name, then call accept_certificate with the result, then call continue_handshake.



Done

The handshake is complete. The negotiated parameters are included.

Fields

ciphersuite: CipherSuite
tls_version: u16

Wire-encoded protocol version (0x0304 for TLS 1.3).

key_exchange_group: KeyExchangeGroup
signature_scheme: SignatureScheme

The signature scheme used by the server’s CertificateVerify.

alpn: &'a [u8]


Closed

The peer has closed the connection.