SignatureScheme

Enum SignatureScheme 

pub enum SignatureScheme {
    Ed25519,
    EcdsaP256Sha256,
    EcdsaP384Sha384,
    RsaPkcs1Sha256,
    RsaPkcs1Sha384,
    RsaPkcs1Sha512,
    RsaPssRsaSha256,
    RsaPssRsaSha384,
    RsaPssRsaSha512,
}
Signature schemes (RFC 8446 4.2.3).

Only the schemes needed for raw public key authentication are listed.

Variants



Ed25519

Ed25519



EcdsaP256Sha256

ECDSA with NIST P-256 and SHA-256



EcdsaP384Sha384

ECDSA with NIST P-384 and SHA-384



RsaPkcs1Sha256

RSA PKCS#1 v1.5 with SHA-256



RsaPkcs1Sha384

RSA PKCS#1 v1.5 with SHA-384



RsaPkcs1Sha512

RSA PKCS#1 v1.5 with SHA-512



RsaPssRsaSha256

RSA-PSS with SHA-256 (RFC 8017)



RsaPssRsaSha384

RSA-PSS with SHA-384 (RFC 8017)



RsaPssRsaSha512

RSA-PSS with SHA-512 (RFC 8017)

Implementations

Source

impl SignatureScheme

pub fn to_wire(self) -> [u8; 2]

TLS wire identifier (two bytes, big-endian).

pub fn from_wire(bytes: [u8; 2]) -> Option<Self>

Parse a signature scheme from its wire identifier.

pub fn secret_key_size(self) -> usize

Expected size of the raw secret key in bytes.

pub fn public_key_size(self) -> usize

Expected size of the raw public key in bytes.

pub fn signature_size(self) -> usize

Signature size in bytes.