pub enum CipherSuite {
TlsAes128GcmSha256,
TlsAes256GcmSha384,
TlsChaCha20Poly1305Sha256,
}Expand description
Cipher suites supported by a CryptoProvider.
In this library the cipher suite prescribes the AEAD cipher, the hash function used throughout the TLS 1.3 key schedule, and the transcript hash.
TLS 1.3 cipher suites always pair one AEAD with one hash.
Variants
TlsAes128GcmSha256
AES-128-GCM with SHA-256
TlsAes256GcmSha384
AES-256-GCM with SHA-384
TlsChaCha20Poly1305Sha256
ChaCha20-Poly1305 with SHA-256
Implementations